KMlogger
========

A Python logging object that provides additional functionality beyond the standard module.


Installation Notes
==================
Only uses standardized Python libraries and KMlogger is hosted on PyPi.  Thus, the easiest way to install it is:
 
 $pip install KMlogger


License
-------

Copyright 2016 Kyle Mede and contributors.

KMlogger is free software made available under the GNU GPLv3 license. 
For details see the license.txt file.